==> cdk-runtime-values-0.10.0-sources.jar: software/amazon/awscdk/runtimevalues/RuntimeValueProps.java <==
package software.amazon.awscdk.runtimevalues;

@javax.annotation.Generated(value = "jsii-pacmak/0.7.6 (build 04cb6bb)", date = "2018-09-27T21:48:22.204Z")
public interface RuntimeValueProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * A namespace for the runtime value.
     * It is recommended to use the name of the library/package that advertises this value.
     */
    java.lang.String getPackage();
    /**
     * A namespace for the runtime value.
     * It is recommended to use the name of the library/package that advertises this value.
     */
    void setPackage(final java.lang.String value);
    /**
     * The value to advertise. Can be either a primitive value or a token.
     */
    java.lang.Object getValue();
    /**
     * The value to advertise. Can be either a primitive value or a token.
     */
    void setValue(final java.lang.Object value);

    /**
     * @return a {@link Builder} of {@link RuntimeValueProps}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link RuntimeValueProps}
     */
    final class Builder {
        private java.lang.String _package;
        @javax.annotation.Nullable
        private java.lang.Object _value;

        /**
         * Sets the value of Package
         * @param value A namespace for the runtime value.
It is recommended to use the name of the library/package that advertises this value.
         * @return {@code this}
         */
        public Builder withPackage(final java.lang.String value) {
            this._package = java.util.Objects.requireNonNull(value, "package is required");
            return this;
        }
        /**
         * Sets the value of Value
         * @param value The value to advertise. Can be either a primitive value or a token.
         * @return {@code this}
         */
        public Builder withValue(@javax.annotation.Nullable final java.lang.Object value) {
            this._value = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link RuntimeValueProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        public RuntimeValueProps build() {
            return new RuntimeValueProps() {
                private java.lang.String $package = java.util.Objects.requireNonNull(_package, "package is required");
                @javax.annotation.Nullable
                private java.lang.Object $value = _value;

                @Override
                public java.lang.String getPackage() {
                    return this.$package;
                }

                @Override
                public void setPackage(final java.lang.String value) {
                    this.$package = java.util.Objects.requireNonNull(value, "package is required");
                }

                @Override
                public java.lang.Object getValue() {
                    return this.$value;
                }

                @Override
                public void setValue(@javax.annotation.Nullable final java.lang.Object value) {
                    this.$value = value;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.runtimevalues.RuntimeValueProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * A namespace for the runtime value.
         * It is recommended to use the name of the library/package that advertises this value.
         */
        @Override
        public java.lang.String getPackage() {
            return this.jsiiGet("package", java.lang.String.class);
        }

        /**
         * A namespace for the runtime value.
         * It is recommended to use the name of the library/package that advertises this value.
         */
        @Override
        public void setPackage(final java.lang.String value) {
            this.jsiiSet("package", java.util.Objects.requireNonNull(value, "package is required"));
        }

        /**
         * The value to advertise. Can be either a primitive value or a token.
         */
        @Override
        @javax.annotation.Nullable
        public java.lang.Object getValue() {
            return this.jsiiGet("value", java.lang.Object.class);
        }

        /**
         * The value to advertise. Can be either a primitive value or a token.
         */
        @Override
        public void setValue(@javax.annotation.Nullable final java.lang.Object value) {
            this.jsiiSet("value", value);
        }
    }
}

==> cdk-runtime-values-0.26.0-sources.jar: software/amazon/awscdk/runtimevalues/RuntimeValueProps.java <==
package software.amazon.awscdk.runtimevalues;

@javax.annotation.Generated(value = "jsii-pacmak/0.7.15 (build e429c41)", date = "2019-03-20T13:00:41.529Z")
public interface RuntimeValueProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * A namespace for the runtime value.
     * It is recommended to use the name of the library/package that advertises this value.
     */
    java.lang.String getPackage();
    /**
     * A namespace for the runtime value.
     * It is recommended to use the name of the library/package that advertises this value.
     */
    void setPackage(final java.lang.String value);
    /**
     * The value to advertise. Can be either a primitive value or a token.
     */
    java.lang.Object getValue();
    /**
     * The value to advertise. Can be either a primitive value or a token.
     */
    void setValue(final java.lang.Object value);

    /**
     * @return a {@link Builder} of {@link RuntimeValueProps}
     */
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link RuntimeValueProps}
     */
    final class Builder {
        private java.lang.String _package;
        private java.lang.Object _value;

        /**
         * Sets the value of Package
         * @param value A namespace for the runtime value.
It is recommended to use the name of the library/package that advertises this value.
         * @return {@code this}
         */
        public Builder withPackage(final java.lang.String value) {
            this._package = java.util.Objects.requireNonNull(value, "package is required");
            return this;
        }
        /**
         * Sets the value of Value
         * @param value The value to advertise. Can be either a primitive value or a token.
         * @return {@code this}
         */
        public Builder withValue(final java.lang.Object value) {
            this._value = java.util.Objects.requireNonNull(value, "value is required");
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link RuntimeValueProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        public RuntimeValueProps build() {
            return new RuntimeValueProps() {
                private java.lang.String $package = java.util.Objects.requireNonNull(_package, "package is required");
                private java.lang.Object $value = java.util.Objects.requireNonNull(_value, "value is required");

                @Override
                public java.lang.String getPackage() {
                    return this.$package;
                }

                @Override
                public void setPackage(final java.lang.String value) {
                    this.$package = java.util.Objects.requireNonNull(value, "package is required");
                }

                @Override
                public java.lang.Object getValue() {
                    return this.$value;
                }

                @Override
                public void setValue(final java.lang.Object value) {
                    this.$value = java.util.Objects.requireNonNull(value, "value is required");
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.runtimevalues.RuntimeValueProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * A namespace for the runtime value.
         * It is recommended to use the name of the library/package that advertises this value.
         */
        @Override
        public java.lang.String getPackage() {
            return this.jsiiGet("package", java.lang.String.class);
        }

        /**
         * A namespace for the runtime value.
         * It is recommended to use the name of the library/package that advertises this value.
         */
        @Override
        public void setPackage(final java.lang.String value) {
            this.jsiiSet("package", java.util.Objects.requireNonNull(value, "package is required"));
        }

        /**
         * The value to advertise. Can be either a primitive value or a token.
         */
        @Override
        public java.lang.Object getValue() {
            return this.jsiiGet("value", java.lang.Object.class);
        }

        /**
         * The value to advertise. Can be either a primitive value or a token.
         */
        @Override
        public void setValue(final java.lang.Object value) {
            this.jsiiSet("value", java.util.Objects.requireNonNull(value, "value is required"));
        }
    }
}
